==> jc-1.4.0.tar.gz: polyglot/visit/InitChecker__24MinMaxInitCount.h <==
// public class polyglot.visit.InitChecker$MinMaxInitCount

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1d8613b16a1f16eb polyglot_visit_InitChecker__24MinMaxInitCount

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_InitChecker__24MinMaxInitCount_H_
#define _JC_polyglot_visit_InitChecker__24MinMaxInitCount_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_visit_InitChecker__24InitCount$object;
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object;

// Typedefs
typedef struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_refs	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_refs;
typedef struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_nonrefs	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$refs	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$refs;
typedef struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$nonrefs	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$object;

typedef const struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vmethods	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vmethods;
typedef const struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtable	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtable;
typedef const struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtype	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtype;

// Constructors
extern void _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$_init$1f785edebe15a465(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *);

// Virtual methods
extern jboolean _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_polyglot_visit_InitChecker__24InitCount$object *_jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$getMax$df6f51203b630deb(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *);
extern struct _jc_polyglot_visit_InitChecker__24InitCount$object *_jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$getMin$8290f504b182b472(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method_info$getMax$df6f51203b630deb;
extern _jc_method _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method_info$getMin$8290f504b182b472;
extern _jc_method _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *_jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$join$8b27d1f7426bd96e(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *);

// Virtual methods structure
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *, struct _jc_java_lang_Object$object *);
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*(*getMax$df6f51203b630deb)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *);
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*(*getMin$8290f504b182b472)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *);
};

// Vtable
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vmethods	polyglot_visit_InitChecker__24MinMaxInitCount;
};

// Vtype
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtype {
	_jc_type			type;
	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_refs {
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*min;
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*max;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$refs {
    _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_refs	polyglot_visit_InitChecker__24MinMaxInitCount;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_nonrefs	polyglot_visit_InitChecker__24MinMaxInitCount;
};

// Object instance structure
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object {
	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtype	*vtype;
	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtype _jc_polyglot_visit_InitChecker__24MinMaxInitCount$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_InitChecker__24MinMaxInitCount, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_InitChecker__24MinMaxInitCount$class_object;

#endif	/* _JC_polyglot_visit_InitChecker__24MinMaxInitCount_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/InitChecker__24MinMaxInitCount.h <==
// public class polyglot.visit.InitChecker$MinMaxInitCount

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1d8613b16a1f16eb polyglot_visit_InitChecker__24MinMaxInitCount

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_InitChecker__24MinMaxInitCount_H_
#define _JC_polyglot_visit_InitChecker__24MinMaxInitCount_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_visit_InitChecker__24InitCount$object;
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object;

// Typedefs
typedef struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_refs	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_refs;
typedef struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_nonrefs	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$refs	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$refs;
typedef struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$nonrefs	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$object;

typedef const struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vmethods	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vmethods;
typedef const struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtable	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtable;
typedef const struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtype	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtype;

// Constructors
extern void _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$_init$1f785edebe15a465(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_InitChecker__24InitCount$object *_jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$getMax$df6f51203b630deb(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_InitChecker__24InitCount$object *_jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$getMin$8290f504b182b472(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method_info$getMax$df6f51203b630deb;
extern _jc_method _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method_info$getMin$8290f504b182b472;
extern _jc_method _jc_polyglot_visit_InitChecker__24MinMaxInitCount$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *_jc_polyglot_visit_InitChecker__24MinMaxInitCount$method$join$8b27d1f7426bd96e(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*(*getMax$df6f51203b630deb)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*(*getMin$8290f504b182b472)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vmethods	polyglot_visit_InitChecker__24MinMaxInitCount;
};

// Vtype
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtype {
	_jc_type			type;
	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_refs {
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*min;
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*max;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$refs {
    _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_refs	polyglot_visit_InitChecker__24MinMaxInitCount;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_InitChecker__24MinMaxInitCount$sub_nonrefs	polyglot_visit_InitChecker__24MinMaxInitCount;
};

// Object instance structure
struct _jc_polyglot_visit_InitChecker__24MinMaxInitCount$object {
	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtype	*vtype;
	_jc_polyglot_visit_InitChecker__24MinMaxInitCount$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_InitChecker__24MinMaxInitCount$vtype _jc_polyglot_visit_InitChecker__24MinMaxInitCount$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_InitChecker__24MinMaxInitCount, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_InitChecker__24MinMaxInitCount$class_object;

#endif	/* _JC_polyglot_visit_InitChecker__24MinMaxInitCount_H_ */
